package cn.com.infosec.crypto.digests;

import cn.com.infosec.crypto.ExtendedDigest;

public class ShortenedDigest implements ExtendedDigest {
   private ExtendedDigest baseDigest;
   private int length;

   public ShortenedDigest(ExtendedDigest baseDigest, int length) {
      if (baseDigest != null) {
         if (length <= baseDigest.getDigestSize()) {
            this.baseDigest = baseDigest;
            this.length = length;
         } else {
            throw new IllegalArgumentException("baseDigest output not large enough to support length");
         }
      } else {
         throw new IllegalArgumentException("baseDigest must not be null");
      }
   }

   public String getAlgorithmName() {
      return this.baseDigest.getAlgorithmName() + "(" + this.length * 8 + ")";
   }

   public int getDigestSize() {
      return this.length;
   }

   public void update(byte in) {
      this.baseDigest.update(in);
   }

   public void update(byte[] in, int inOff, int len) {
      this.baseDigest.update(in, inOff, len);
   }

   public int doFinal(byte[] out, int outOff) {
      ShortenedDigest var10000 = this;
      byte[] var3;
      byte[] var10001 = var3 = new byte[this.baseDigest.getDigestSize()];
      this.baseDigest.doFinal(var3, 0);
      int var4 = this.length;
      System.arraycopy(var10001, 0, out, outOff, var4);
      return var10000.length;
   }

   public void reset() {
      this.baseDigest.reset();
   }

   public int getByteLength() {
      return this.baseDigest.getByteLength();
   }
}
